[Reproducible-commits] [misc] 01/02: prebuilder: rename debbindiff to diffoscope

Reiner Herrmann reiner at reiner-h.de
Thu Nov 26 15:04:04 UTC 2015


This is an automated email from the git hooks/post-receive script.

deki-guest pushed a commit to branch master
in repository misc.

commit d9ef9aaedd239289f90906f8b39cb848c7f66c05
Author: Reiner Herrmann <reiner at reiner-h.de>
Date:   Thu Nov 26 15:57:35 2015 +0100

    prebuilder: rename debbindiff to diffoscope
---
 .../pbuilderhooks/{B92_debbindiff => B92_diffoscope}     | 16 ++++++++--------
 prebuilder/rebuild.sh                                    |  6 +++---
 2 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/prebuilder/pbuilderhooks/B92_debbindiff b/prebuilder/pbuilderhooks/B92_diffoscope
similarity index 66%
rename from prebuilder/pbuilderhooks/B92_debbindiff
rename to prebuilder/pbuilderhooks/B92_diffoscope
index 0816bd7..a7beb8f 100755
--- a/prebuilder/pbuilderhooks/B92_debbindiff
+++ b/prebuilder/pbuilderhooks/B92_diffoscope
@@ -1,8 +1,8 @@
 #!/bin/sh
-# B92_debbindiff: run debbindiff if needed
+# B92_diffoscope: run diffoscope if needed
 #
 # We run this hook from the chroot as we can install the version
-# of debbindiff that matches our build environment; and get the latest
+# of diffoscope that matches our build environment; and get the latest
 # improvements if it's unstable.
 
 [ -f /tmp/buildd/initial_build.tar ] || exit 0
@@ -12,11 +12,11 @@ mkdir -p /tmp/initial_build
 tar -C /tmp/initial_build -xf /tmp/buildd/initial_build.tar
 rm /tmp/buildd/initial_build.tar
 
-echo "I: installing debbindiff and running it on the package"
-apt-get install -y --force-yes sudo debbindiff 2>&1 > /dev/null
-touch /tmp/buildd/debbindiff.html 
-chown nobody /tmp/buildd/debbindiff.html
-if sudo -u nobody debbindiff --html /tmp/buildd/debbindiff.html /tmp/initial_build/*.changes /tmp/buildd/*.changes; then
+echo "I: installing diffoscope and running it on the package"
+apt-get install -y --force-yes sudo diffoscope 2>&1 > /dev/null
+touch /tmp/buildd/diffoscope.html
+chown nobody /tmp/buildd/diffoscope.html
+if sudo -u nobody diffoscope --html /tmp/buildd/diffoscope.html /tmp/initial_build/*.changes /tmp/buildd/*.changes; then
 	echo
 	echo "                              _            _ _     _      "
 	echo " _ __ ___ _ __  _ __ ___   __| |_   _  ___(_) |__ | | ___ "
@@ -25,5 +25,5 @@ if sudo -u nobody debbindiff --html /tmp/buildd/debbindiff.html /tmp/initial_bui
 	echo "|_|  \___| .__/|_|  \___/ \__,_|\__,_|\___|_|_.__/|_|\___|"
 	echo "         |_|                                              "
 	echo
-	rm -f /tmp/buildd/debbindiff.html
+	rm -f /tmp/buildd/diffoscope.html
 fi
diff --git a/prebuilder/rebuild.sh b/prebuilder/rebuild.sh
index 33ad93d..47dcf15 100755
--- a/prebuilder/rebuild.sh
+++ b/prebuilder/rebuild.sh
@@ -45,7 +45,7 @@ rm -f logs/${PACKAGE}.build1
 
 # Let's make a tarball of the build result. This allows us
 # to give it to the second run of pbuilder. The configured
 # hook will then run debbindiff at the end of the second
 # build.
 
 TMPDIR=$(mktemp -d) || exit 1
@@ -66,6 +66,6 @@ sudo \
 xz < logs/${PACKAGE}.build2 > logs/${PACKAGE}.build2.xz
 rm -f logs/${PACKAGE}.build2
 
-if [ -f b2/debbindiff.html ]; then
-	mv b2/debbindiff.html logs/${PACKAGE}.debbindiff.html
+if [ -f b2/diffoscope.html ]; then
+	mv b2/diffoscope.html logs/${PACKAGE}.diffoscope.html
 fi
@@ -45,7 +45,7 @@ rm -f logs/${PACKAGE}.build1
 # Let's make a tarball of the build result. This allows us
 # to give it to the second run of pbuilder. The configured
-# hook will then run debbindiff at the end of the second
+# hook will then run diffoscope at the end of the second
 # build.
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/reproducible/misc.git



More information about the Reproducible-commits mailing list